California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2023 through 2024 Historical
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2023 - 2024 Election Dates: 1. SPECIAL ELECTION Thursday, 11/30/23 2. PRIMARY ELECTION Tuesday, 3/5/24 3. GENERAL ELECTION Tuesday, 11/5/24
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.